tomotok.core package
====================

.. automodule:: tomotok.core
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    tomotok.core.geometry
    tomotok.core.inversions
    tomotok.core.io
    tomotok.core.tools

Submodules
----------

tomotok.core.derivative module
------------------------------

.. automodule:: tomotok.core.derivative
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.phantoms module
----------------------------

.. automodule:: tomotok.core.phantoms
    :members:
    :undoc-members:
    :show-inheritance:


